import Vue from "vue";
import VueCookie from "vue-cookie";
const number_input_props = (message, precision = 0, nonzero = false) => {
  return {
    type: "number",
    step: 1,
    precision,
    min: 0, //! 这个选项似乎没有用
    span: 8,
    rules: [{
      required: true,
      message,
      trigger: 'blur'
    }, {
      validator: (_, v, callback) => {
        callback((v > 0 || v === 0 && !nonzero) ? undefined : new Error(nonzero ? "应当为正数" : "应当为非负数"))
      },
      trigger: 'blur'
    }]
  }
}

const radio_prop = (label, prop, options, etc) => {
  return {
    label,
    prop,
    type: 'radio',
    span: 12,
    row: true,
    dicData: options.map(v => {
      return {
        value: v,
        label: v,
      }
    }),
    rules: [{
      required: true,
      message: label + " 为必填项",
      trigger: 'blur'
    }]
  }
}

export default {
  labelWidth: 100,
  column: [
    {
      label: '',
      type: "title",
      prop: 'title',
      row: true,
      labelWidth: 0,
    },
    {
      label: '产品名称',
      prop: 'name',
      type: 'input',
      span: 12,
      row: true,
      rules: [{
        required: true,
        message: "请输入商品名称",
      }]
    }, {
      label: '产品描述',
      prop: 'desc',
      type: 'textarea',
      minRows: 3,
      maxRows: 5,
      row: true,
      rules: [{
        required: true,
        message: "请输入商品描述",
      }]
    }, {
      label: "价格(￥)",
      prop: "price",
      ...number_input_props("请输入产品价格", 2),
      row: true,

    }, {
      label: "运费(￥)",
      ...number_input_props("请输入运费价格", 2),
      prop: "deliverPrice",
      row: true,
    }, {
      label: "库存(件)",
      prop: "stockAmount",
      ...number_input_props("请输入库存数"),
      row: true,
    },
    radio_prop("展示平台", "platform", ["全部", "商城", "直播间"]),
    {
      ...radio_prop("商品类型", "kind", ["自营", "第三方链接"]),
      control: (v) => {
        return {
          link: {
            display: v === '第三方链接'
          }
        }
      }
    },
    {
      label: '第三方链接',
      prop: 'link',
      span: 18,
      row: true,
      rules: [{
        required: true,
        message: "第三方链接 为必填项",
        trigger: 'blur'
      }],
      display: false,
    }, {
      label: '需要地址',
      prop: 'needAddr',
      type: 'switch',
      dicData: [{
        label: '否',
        value: false
      }, {
        label: '是',
        value: true
      }],
      value: true,
    }, {
      label: "商品分类",
      prop: "goodsTypeList",
      formslot: true,
      span: 24,
      row: true,
    }, {
      label: '封面图片',
      prop: 'cover',
      type: 'upload',
      listType: 'picture-card',
      span: 24,
      accept: 'image/png, image/jpeg',
      limit: 1,
      fileSize: 5 * 1024,
      propsHttp: {
        url: "data"
      },
      headers: {
        "Authorization": VueCookie.get("Authorization")
      },
      tip: '只能上传jpg/png图片，且不超过5MiB',
      action: `${process.env.VUE_APP_BASE_API || ""}/file/upload`,
      multiple: false
    }
  ]
}