/**
 * 环信IM基础构件
 */
import WebIM from 'easemob-websdk';
import config from "./WebIMConfig";

export default class WebIMUtils {

    /** 
     * 构造方法中进行IM客户端初始化
     * @param roomId 聊天室编号
     * @param username 用户名
     * @param password 密码
     * @param callback 收到消息后的回调
     */
    constructor(roomId, username, password, callback, disconnect) {
        this.conn = new WebIM.connection({
            ...config
        });
        this.conn.addEventHandler("handlerId", {
            onDisconnected: () => {
                console.warn("环信IM用户掉线了");
                disconnect();
            },onTextMessage: (message) => {
                console.warn("收到文字信息：", message);
                console.warn(this)
                if (message.to == roomId) {
                    if (message.ext) {
                        if (message.ext.push_type == "user_online") {
                        } else if (message.ext.push_type == "product_online") {
                        } else if (message.ext.push_type == "change_live_state") {
                        }
                        else {
                            console.warn("收到聊天消息");
                            callback({
                                nickname: message.ext.nickname, 
                                msg: message.msg,
                                imUserId: message.from,
                                time: message.time
                            })
                        }
                    }
                }
            },onConnected: () => {
                this.enterChatroom(roomId);
            }
        });
        this.handleLogin(username, password);
    }
    handleLogin(user, accessToken) {
        return new Promise((resolve, reject) => {
            let options = {
                user,
                accessToken
            };
            if (this.conn != null) {
                this.conn.open(options).then((res) => {
                    resolve(res);
                }).catch((err) => {
                    reject(err)
                });
            } else {
                reject("客户端还未就绪")
            }
        })
    }

    handleLogout() {
        if (this.conn != null) {
            this.conn.close();
        }
    }

    /**
     * 环信用户进入聊天室
     * @param {*} roomId 聊天室编号
     */
    enterChatroom(roomId) {
        return new Promise((resolve, reject) => {
            this.conn.joinChatRoom({
                roomId,
                message: "进入聊天室"
            }).then(() => {
                resolve();
            }).catch((error) => {
                console.warn(error);
                reject();
            })
        })
    }


    /**
     * 发送聊天消息
     * @param {*} roomId 聊天室编号
     * @param {*} message 发送的消息
     * @param {*} nickname 发送者信息
     * @returns 
     */
    sendTextMessage({to, nickname, chatType, message, replyMsg}) {
        console.warn("发送聊天信息")
        return new Promise((resolve, reject) => {
            let msg = WebIM.message.create({
                type: "txt",
                msg: message,
                to,
                chatType,
                ext: {
                    nickname
                }
            });
            if (replyMsg != null) {
                msg.ext.replyMsg = replyMsg;
            }
            this.conn.send(msg).then(() => {
                // this.showRoomMsg(nickname, message)
                resolve();
            }).catch((err) => {
                reject(err);
            })
        })
    }

    dispose() {
        this.conn.close();
        delete this.conn;
    }
}